==> 0.0.7.tar.gz: lib/NetmeraUser.dart <==
///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
class NetmeraUser {
  static const int GENDER_MALE = 0;
  static const int GENDER_FEMALE = 1;
  static const int GENDER_NOT_SPECIFIED = 2;

  static const int MARITAL_STATUS_SINGLE = 0;
  static const int MARITAL_STATUS_MARRIED = 1;
  static const int MARITAL_STATUS_NOT_SPECIFIED = 2;

  String _userId;
  String _email;
  String _msisdn;
  String _name;
  String _surname;
  List<String> _externalSegments;
  int _gender;
  int _dateOfBirth;
  int _maritalStatus;
  int _childCount;
  String _country;
  String _state;
  String _city;
  String _district;
  String _occupation;
  String _industry;
  String _favoriteTeam;
  String _language;

  String getUserId() => _userId;

  setUserId(String value) {
    _userId = value;
  }

  String getEmail() => _email;

  setEmail(String value) {
    _email = value;
  }

  String getMsisdn() => _msisdn;

  setMsisdn(String value) {
    _msisdn = value;
  }

  String getName() => _name;

  setName(String value) {
    _name = value;
  }

  String getSurname() => _surname;

  setSurname(String value) {
    _surname = value;
  }

  List<String> getExternalSegments() => _externalSegments;

  setExternalSegments(List<String> value) {
    _externalSegments = value;
  }

  int getGender() => _gender;

  setGender(int value) {
    _gender = value;
  }

  int getDateOfBirth() => _dateOfBirth;

  setDateOfBirth(int value) {
    _dateOfBirth = value;
  }

  int getMaritalStatus() => _maritalStatus;

  setMaritalStatus(int value) {
    _maritalStatus = value;
  }

  int getChildCount() => _childCount;

  setChildCount(int value) {
    _childCount = value;
  }

  String getCountry() => _country;

  setCountry(String value) {
    _country = value;
  }

  String getState() => _state;

  setState(String value) {
    _state = value;
  }

  String getCity() => _city;

  setCity(String value) {
    _city = value;
  }

  String getDistrict() => _district;

  setDistrict(String value) {
    _district = value;
  }

  String getOccupation() => _occupation;

  setOccupation(String value) {
    _occupation = value;
  }

  String getIndustry() => _industry;

  setIndustry(String value) {
    _industry = value;
  }

  String getFavoriteTeam() => _favoriteTeam;

  setFavoriteTeam(String value) {
    _favoriteTeam = value;
  }

  String getLanguage() => _language;

  setLanguage(String value) {
    _language = value;
  }

  Map<String, dynamic> toJson() => {
        'userId': _userId,
        'email': _email,
        'msisdn': _msisdn,
        'pa': _name,
        'pb': _surname,
        'pc': _externalSegments,
        'pd': _gender,
        'pe': _dateOfBirth,
        'pf': _maritalStatus,
        'pg': _childCount,
        'ph': _country,
        'pi': _state,
        'pj': _city,
        'pk': _district,
        'pl': _occupation,
        'pm': _industry,
        'pn': _favoriteTeam,
        'po': _language
      };
}

==> 2.1.7.tar.gz: lib/NetmeraUser.dart <==
///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
class NetmeraUser {
  static const int GENDER_MALE = 0;
  static const int GENDER_FEMALE = 1;
  static const int GENDER_NOT_SPECIFIED = 2;

  static const int MARITAL_STATUS_SINGLE = 0;
  static const int MARITAL_STATUS_MARRIED = 1;
  static const int MARITAL_STATUS_NOT_SPECIFIED = 2;

  String? _userId;
  String? _email;
  String? _msisdn;
  String? _name;
  String? _surname;
  List<String>? _externalSegments;
  int? _gender;
  int? _dateOfBirth;
  int? _maritalStatus;
  int? _childCount;
  String? _country;
  String? _state;
  String? _city;
  String? _district;
  String? _occupation;
  String? _industry;
  String? _favoriteTeam;
  String? _language;

  String? getUserId() => _userId;

  setUserId(String value) {
    _userId = value;
  }

  String? getEmail() => _email;

  setEmail(String value) {
    _email = value;
  }

  String? getMsisdn() => _msisdn;

  setMsisdn(String value) {
    _msisdn = value;
  }

  String? getName() => _name;

  setName(String value) {
    _name = value;
  }

  String? getSurname() => _surname;

  setSurname(String value) {
    _surname = value;
  }

  List<String>? getExternalSegments() => _externalSegments;

  setExternalSegments(List<String> value) {
    _externalSegments = value;
  }

  int? getGender() => _gender;

  setGender(int value) {
    _gender = value;
  }

  int? getDateOfBirth() => _dateOfBirth;

  setDateOfBirth(int value) {
    _dateOfBirth = value;
  }

  int? getMaritalStatus() => _maritalStatus;

  setMaritalStatus(int value) {
    _maritalStatus = value;
  }

  int? getChildCount() => _childCount;

  setChildCount(int value) {
    _childCount = value;
  }

  String? getCountry() => _country;

  setCountry(String value) {
    _country = value;
  }

  String? getState() => _state;

  setState(String value) {
    _state = value;
  }

  String? getCity() => _city;

  setCity(String value) {
    _city = value;
  }

  String? getDistrict() => _district;

  setDistrict(String value) {
    _district = value;
  }

  String? getOccupation() => _occupation;

  setOccupation(String value) {
    _occupation = value;
  }

  String? getIndustry() => _industry;

  setIndustry(String value) {
    _industry = value;
  }

  String? getFavoriteTeam() => _favoriteTeam;

  setFavoriteTeam(String value) {
    _favoriteTeam = value;
  }

  String? getLanguage() => _language;

  setLanguage(String value) {
    _language = value;
  }

  Map<String, dynamic> toJson() => {
        'userId': _userId,
        'email': _email,
        'msisdn': _msisdn,
        'pa': _name,
        'pb': _surname,
        'pc': _externalSegments,
        'pd': _gender,
        'pe': _dateOfBirth,
        'pf': _maritalStatus,
        'pg': _childCount,
        'ph': _country,
        'pi': _state,
        'pj': _city,
        'pk': _district,
        'pl': _occupation,
        'pm': _industry,
        'pn': _favoriteTeam,
        'po': _language
      };
}
